import"./rolldown-runtime-DIIn1E2Q.js";import{n as e}from"./vendor-zod-AyupqgYk.js";import{o as t}from"./i18n-CF_88JEG.js";var n=e.object({apiKey:e.string().trim().startsWith(`comfyui-`,t(`validation.prefix`,{prefix:`comfyui-`})).length(72,t(`validation.length`,{length:72}))}),r=e.object({email:e.string().email(t(`validation.invalidEmail`)).min(1,t(`validation.required`)),password:e.string().min(1,t(`validation.required`))}),i=e.object({password:e.string().min(8,t(`validation.minLength`,{length:8})).max(32,t(`validation.maxLength`,{length:32})).regex(/[A-Z]/,t(`validation.password.uppercase`)).regex(/[a-z]/,t(`validation.password.lowercase`)).regex(/\d/,t(`validation.password.number`)).regex(/[^A-Za-z0-9]/,t(`validation.password.special`)),confirmPassword:e.string().min(1,t(`validation.required`))}),a=i.refine(e=>e.password===e.confirmPassword,{message:t(`validation.password.match`),path:[`confirmPassword`]}),o=i.extend({email:e.string().email(t(`validation.invalidEmail`)).min(1,t(`validation.required`))}).refine(e=>e.password===e.confirmPassword,{message:t(`validation.password.match`),path:[`confirmPassword`]});export{a as i,r as n,o as r,n as t};
//# sourceMappingURL=signInSchema-PuiTYtwA.js.map