import"./rolldown-runtime-DIIn1E2Q.js";import{G as e,K as t,M as n,R as r,Rt as i,_ as a,et as o,j as s,ut as c,vt as l}from"./vendor-vue-core-DO0afONr.js";import{t as u}from"./src-NuWuoO1R.js";var d=r({__name:`Textarea`,props:e({class:{}},{modelValue:{},modelModifiers:{}}),emits:[`update:modelValue`],setup(e){let r=n(e,[`class`]),d=c(e,`modelValue`);return(n,c)=>l((o(),s(`textarea`,t(r,{"onUpdate:modelValue":c[0]||=e=>d.value=e,class:i(u)(`flex min-h-16 w-full rounded-lg border-none bg-secondary-background px-3 py-2 text-sm text-base-foreground placeholder:text-muted-foreground focus-visible:ring-1 focus-visible:ring-border-default focus-visible:outline-none disabled:pointer-events-none disabled:opacity-50`,e.class)}),null,16)),[[a,d.value]])}});export{d as t};
//# sourceMappingURL=Textarea-DSw8aTZE.js.map