import"./rolldown-runtime-DIIn1E2Q.js";import{D as e,R as t,et as n,k as r}from"./vendor-vue-core-DO0afONr.js";import{t as i}from"./TopbarBadge-CkkEYpW4.js";var a=t({__name:`CloudBadge`,props:{displayMode:{default:`full`},reverseOrder:{type:Boolean},noPadding:{type:Boolean},backgroundColor:{default:`var(--comfy-menu-bg)`}},setup(t){let a=e(()=>({icon:`icon-[lucide--cloud]`,text:`Comfy Cloud`}));return(e,t)=>(n(),r(i,{badge:a.value,"display-mode":e.displayMode,"reverse-order":e.reverseOrder,"no-padding":e.noPadding,"background-color":e.backgroundColor},null,8,[`badge`,`display-mode`,`reverse-order`,`no-padding`,`background-color`]))}});export{a as t};
//# sourceMappingURL=CloudBadge-Dz3lnhIm.js.map