import"./vendor-other-CiPV8GBG.js";import"./vendor-markdown-Da9QPS2x.js";import"./formatUtil-CeKPWstn.js";import"./electronDownloadStore-DudKQmD7.js";import{n as e}from"./missingModelDownload-Elln16Ad.js";export{e as fetchModelMetadata};