import"./rolldown-runtime-DIIn1E2Q.js";import{O as e,R as t,Ut as n,et as r,j as i}from"./vendor-vue-core-DO0afONr.js";var a={class:`flex flex-col items-start gap-0 self-stretch`},o={class:`flex items-center gap-2 py-2`},s={class:`text-sm text-text-primary`},c={class:`flex items-center gap-2 py-2`},l={class:`text-sm text-text-primary`},u={class:`flex items-center gap-2 py-2`},d={class:`text-sm text-text-primary`},f=t({__name:`SubscriptionBenefits`,props:{isFreeTier:{type:Boolean,default:!1}},setup(t){return(t,f)=>(r(),i(`div`,a,[e(`div`,o,[f[0]||=e(`i`,{class:`pi pi-check text-xs text-text-primary`},null,-1),e(`span`,s,n(t.isFreeTier?t.$t(`subscription.benefits.benefit1FreeTier`):t.$t(`subscription.benefits.benefit1`)),1)]),e(`div`,c,[f[1]||=e(`i`,{class:`pi pi-check text-xs text-text-primary`},null,-1),e(`span`,l,n(t.$t(`subscription.benefits.benefit2`)),1)]),e(`div`,u,[f[2]||=e(`i`,{class:`pi pi-check text-xs text-text-primary`},null,-1),e(`span`,d,n(t.$t(`subscription.benefits.benefit3`)),1)])]))}});export{f as t};
//# sourceMappingURL=SubscriptionBenefits-AQUTEUkF.js.map