import"./rolldown-runtime-DIIn1E2Q.js";import{dt as e}from"./vendor-primevue-BDZ_jj__.js";import"./vendor-firebase-D7u00oy9.js";import{F as t,I as n,O as r,R as i,Ut as a,_t as o,et as s,j as c,kt as l}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-CiPV8GBG.js";import"./useFeatureFlags-CeS8LuDc.js";import"./api-Cw7jP9TY.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-Bsa2N3Sq.js";import{n as u}from"./vendor-i18n-JbyM4Qz7.js";import"./i18n-CF_88JEG.js";import"./vendor-reka-ui-B53kLmAc.js";import{t as d}from"./Button-Ca3rDegY.js";import{Ri as f}from"./dialogService-CfgsFapJ.js";import"./formatUtil-CeKPWstn.js";import{t as p}from"./dialogStore-G2juoay4.js";import"./userStore-Czt6jT20.js";import"./useErrorHandling-DXaBpHI1.js";import"./extensionStore-MnMxnUwx.js";import"./useExternalLink-BItqlDxr.js";import"./vendor-tiptap-Bk1lVUYZ.js";import"./markdownRendererUtil-_EbNpPBW.js";import"./Popover-CXKWNrM3.js";import"./electronDownloadStore-DudKQmD7.js";var m={class:`flex w-full max-w-[360px] flex-col rounded-2xl border border-border-default bg-base-background`},h={class:`flex h-12 items-center justify-between border-b border-border-default px-4`},g={class:`m-0 text-sm font-normal text-base-foreground`},_=[`aria-label`],v={class:`p-4`},y={class:`m-0 text-sm text-muted-foreground`},b={class:`flex items-center justify-end gap-4 p-4`},x=i({__name:`RevokeInviteDialogContent`,props:{inviteId:{}},setup(i){let x=p(),S=f(),C=e(),{t:w}=u(),T=l(!1);function onCancel(){x.closeDialog({key:`revoke-invite`})}async function onRevoke(){T.value=!0;try{await S.revokeInvite(i.inviteId),x.closeDialog({key:`revoke-invite`})}catch(e){C.add({severity:`error`,summary:w(`g.error`),detail:e instanceof Error?e.message:void 0})}finally{T.value=!1}}return(e,i)=>(s(),c(`div`,m,[r(`div`,h,[r(`h2`,g,a(e.$t(`workspacePanel.revokeInviteDialog.title`)),1),r(`button`,{class:`focus-visible:ring-secondary-foreground cursor-pointer rounded-sm border-none bg-transparent p-0 text-muted-foreground transition-colors hover:text-base-foreground focus-visible:ring-1 focus-visible:outline-none`,"aria-label":e.$t(`g.close`),onClick:onCancel},i[0]||=[r(`i`,{class:`pi pi-times size-4`},null,-1)],8,_)]),r(`div`,v,[r(`p`,y,a(e.$t(`workspacePanel.revokeInviteDialog.message`)),1)]),r(`div`,b,[n(d,{variant:`muted-textonly`,onClick:onCancel},{default:o(()=>[t(a(e.$t(`g.cancel`)),1)]),_:1}),n(d,{variant:`destructive`,size:`lg`,loading:T.value,onClick:onRevoke},{default:o(()=>[t(a(e.$t(`workspacePanel.revokeInviteDialog.revoke`)),1)]),_:1},8,[`loading`])])]))}});export{x as default};
//# sourceMappingURL=RevokeInviteDialogContent-DJn9FAwY.js.map