import"./rolldown-runtime-DIIn1E2Q.js";import{F as e,I as t,O as n,R as r,Rt as i,S as a,Ut as o,Z as s,_t as c,et as l,j as u,nt as d}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-CiPV8GBG.js";import{n as f}from"./vendor-i18n-JbyM4Qz7.js";import{t as p}from"./telemetry-B-mZAUOK.js";import"./vendor-reka-ui-B53kLmAc.js";import{t as m}from"./Button-Ca3rDegY.js";import{t as h}from"./dialogStore-G2juoay4.js";import"./cloud-subscription-Ohc_ectq.js";var g={class:`relative grid h-full grid-cols-5`},_={class:`col-span-3 flex flex-col justify-between p-8`},v={class:`flex flex-col gap-4`},y={class:`text-sm font-semibold text-text-primary`},b={class:`m-0 text-sm text-text-secondary`},x={class:`mt-6 flex flex-col items-start gap-0 self-stretch`},S={class:`text-sm text-text-primary`},C={class:`flex flex-col gap-2 pt-8`},w={class:`m-0 text-center text-xs text-text-secondary`},T=r({__name:`CloudNotificationContent`,setup(r){let{t:T}=f();s(()=>{p()?.trackUiButtonClicked({button_id:`cloud_notification_modal_impression`})});function onDismiss(){p()?.trackUiButtonClicked({button_id:`cloud_notification_continue_locally_clicked`}),h().closeDialog()}function onExplore(){p()?.trackUiButtonClicked({button_id:`cloud_notification_explore_cloud_clicked`});let e=new URLSearchParams({utm_source:`desktop`,utm_medium:`onload-modal`,utm_campaign:`local-to-cloud-conversion`,utm_id:`desktop-onload-modal`,utm_source_platform:`mac-desktop`});window.open(`https://www.comfy.org/cloud?${e}`,`_blank`,`noopener,noreferrer`),h().closeDialog()}return(r,s)=>(l(),u(`div`,g,[t(m,{size:`unset`,variant:`muted-textonly`,class:`absolute top-2.5 right-2.5 z-10 size-8 rounded-full p-0 text-white hover:bg-white/20`,"aria-label":i(T)(`g.close`),onClick:onDismiss},{default:c(()=>s[0]||=[n(`i`,{class:`pi pi-times`},null,-1)]),_:1},8,[`aria-label`]),s[2]||=n(`div`,{class:`relative col-span-2 flex items-center justify-center overflow-hidden rounded-sm`},[n(`video`,{autoplay:``,loop:``,muted:``,playsinline:``,class:`-ml-[20%] h-full min-w-5/4 object-cover p-0`},[n(`source`,{src:``+new URL(`images/cloud-subscription.webm`,import.meta.url).href,type:`video/webm`})])],-1),n(`div`,_,[n(`div`,null,[n(`div`,v,[n(`div`,y,o(i(T)(`cloudNotification.title`)),1),n(`p`,b,o(i(T)(`cloudNotification.message`)),1)]),n(`div`,x,[(l(),u(a,null,d(4,e=>n(`div`,{key:e,class:`flex items-center gap-2 py-2`},[s[1]||=n(`i`,{class:`pi pi-check text-xs text-text-primary`},null,-1),n(`span`,S,o(i(T)(`cloudNotification.feature${e}Title`)),1)])),64))])]),n(`div`,C,[t(m,{variant:`primary`,size:`lg`,class:`w-full font-bold`,onClick:onExplore},{default:c(()=>[e(o(i(T)(`cloudNotification.exploreCloud`)),1)]),_:1}),t(m,{variant:`textonly`,size:`sm`,class:`w-full`,onClick:onDismiss},{default:c(()=>[e(o(i(T)(`cloudNotification.continueLocally`)),1)]),_:1}),n(`p`,w,o(i(T)(`cloudNotification.footer`)),1)])])]))}});export{T as default};
//# sourceMappingURL=CloudNotificationContent-BlQiUucO.js.map