import"./rolldown-runtime-DIIn1E2Q.js";import{D as e,Ht as t,R as n,Ut as r,et as i,j as a}from"./vendor-vue-core-DO0afONr.js";var o=n({__name:`WorkspaceProfilePic`,props:{workspaceName:{}},setup(n){let o=e(()=>n.workspaceName?.charAt(0)?.toUpperCase()??`?`),s=e(()=>{let e=o.value.charCodeAt(0);function mulberry32(e){return function(){let t=e+=1831565813;return t=Math.imul(t^t>>>15,t|1),t^=t+Math.imul(t^t>>>7,t|61),((t^t>>>14)>>>0)/4294967296}}let t=mulberry32(e),n=Math.floor(t()*360),r=(n+40+Math.floor(t()*80))%360,i=65+Math.floor(t()*20),a=55+Math.floor(t()*15);return`linear-gradient(135deg, hsl(${n}, ${i}%, ${a}%), hsl(${r}, ${i}%, ${a}%))`});return(e,n)=>(i(),a(`div`,{class:`flex aspect-square size-8 items-center justify-center rounded-md text-base font-semibold text-white`,style:t({background:s.value,textShadow:`0 1px 2px rgba(0, 0, 0, 0.2)`})},r(o.value),5))}});export{o as t};
//# sourceMappingURL=WorkspaceProfilePic-CE1J_Uz7.js.map