import"./rolldown-runtime-DIIn1E2Q.js";import{Bt as e,I as t,K as n,R as r,Rt as i,S as a,_t as o,et as s,j as c,k as l,kt as u,nt as d}from"./vendor-vue-core-DO0afONr.js";import{W as f}from"./vendor-vueuse-DUMtJaL2.js";import{Et as p,_ as m,g as h,h as g,v as _}from"./vendor-reka-ui-B53kLmAc.js";import{t as v}from"./src-NuWuoO1R.js";var y=r({__name:`Slider`,props:{defaultValue:{},modelValue:{},disabled:{type:Boolean},orientation:{},dir:{},inverted:{type:Boolean},min:{},max:{},step:{},minStepsBetweenThumbs:{},thumbAlignment:{},asChild:{type:Boolean},as:{},name:{},required:{type:Boolean},class:{}},emits:[`update:modelValue`,`valueCommit`],setup(r,{emit:y}){let b=r,x=u(!1),setPressed=e=>{x.value=e},S=y,C=p(f(b,`class`),S);return(r,u)=>(s(),l(i(_),n({"data-slot":`slider`,class:i(v)(`relative flex w-full touch-none items-center select-none data-disabled:opacity-50`,`data-[orientation=vertical]:h-full data-[orientation=vertical]:min-h-44 data-[orientation=vertical]:w-auto data-[orientation=vertical]:flex-col`,b.class)},i(C),{onSlideStart:u[0]||=()=>setPressed(!0),onSlideMove:u[1]||=()=>setPressed(!0),onSlideEnd:u[2]||=()=>setPressed(!1)}),{default:o(({modelValue:n})=>[t(i(g),{"data-slot":`slider-track`,class:e(i(v)(`relative grow overflow-hidden rounded-full bg-node-stroke`,`cursor-pointer overflow-visible`,`before:absolute before:-inset-2 before:block before:bg-transparent`,`data-[orientation=horizontal]:h-0.5 data-[orientation=horizontal]:w-full`,`data-[orientation=vertical]:h-full data-[orientation=vertical]:w-0.5`))},{default:o(()=>[t(i(m),{"data-slot":`slider-range`,class:`absolute bg-node-component-surface-highlight data-[orientation=horizontal]:h-full data-[orientation=vertical]:w-full`})]),_:1},8,[`class`]),(s(!0),c(a,null,d(n,(t,n)=>(s(),l(i(h),{key:n,"data-slot":`slider-thumb`,class:e(i(v)(`block size-3.5 shrink-0 rounded-full bg-node-component-surface-highlight shadow-sm ring-node-component-surface-selected transition-[color,box-shadow]`,`cursor-grab`,`before:absolute before:-inset-1 before:block before:rounded-full before:bg-transparent`,`hover:ring-2 focus-visible:ring-2 focus-visible:outline-hidden disabled:pointer-events-none disabled:opacity-50`,{"cursor-grabbing":x.value}))},null,8,[`class`]))),128))]),_:1},16,[`class`]))}});export{y as t};
//# sourceMappingURL=Slider-D50kmiD4.js.map