const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./CloudLayoutView-5ImVSwWL.js","./_plugin-vue_export-helper-Wc9cjhKh.js","./rolldown-runtime-DIIn1E2Q.js","./vendor-primevue-BDZ_jj__.js","./vendor-vue-core-DO0afONr.js","./dialogService-CfgsFapJ.js","./vendor-other-CiPV8GBG.js","./vendor-firebase-D7u00oy9.js","./vendor-three-ByVNcHWs.js","./vendor-tiptap-Bk1lVUYZ.js","./vendor-reka-ui-B53kLmAc.js","./vendor-i18n-JbyM4Qz7.js","./vendor-sentry-DFQqneKv.js","./vendor-vueuse-DUMtJaL2.js","./vendor-axios-B2OLCPxZ.js","./vendor-markdown-Da9QPS2x.js","./vendor-zod-AyupqgYk.js","./formatUtil-CeKPWstn.js","./src-NuWuoO1R.js","./Loader-Bkgmd-vZ.js","./Popover-CXKWNrM3.js","./Button-Ca3rDegY.js","./SelectValue-DvVNo6Es.js","./api-Cw7jP9TY.js","./vendor-yjs-BsN9BCzH.js","./i18n-CF_88JEG.js","./widget-BH5tDli6.js","./types-DPJvCrdo.js","./colorUtil-Bsa2N3Sq.js","./extensionStore-MnMxnUwx.js","./useErrorHandling-DXaBpHI1.js","./useExternalLink-BItqlDxr.js","./envUtil-DWap3SmU.js","./useFeatureFlags-CeS8LuDc.js","./VideoPlayOverlay-HaJSLuhi.js","./assetMetadataUtils-xfixkyW2.js","./telemetry-B-mZAUOK.js","./dialogStore-G2juoay4.js","./electronDownloadStore-DudKQmD7.js","./userStore-Czt6jT20.js","./widgetTypes-B3taJqHN.js","./markdownRendererUtil-_EbNpPBW.js","./GlobalToast-BF8qxRmA.js","./BaseViewTemplate-WD8I71wC.js","./vendor-other-CaaUC6Qe.css","./dialogService-CRVO3AcS.css","./CloudLayoutView-C-gB3SQs.css","./CloudLoginView-DHbWe4RP.js","./previousFullPath-DWscR1ic.js","./signInSchema-PuiTYtwA.js","./CloudLoginView-BNhCiCVb.css","./useCurrentUser-zqQiqncr.js","./CloudSignupView-ZIdgJeyh.js","./PasswordFields-DqvHzjK4.js","./SignUpForm-Dc6zuXxy.js","./CloudSignupView-C0QtxnNH.css","./CloudForgotPasswordView-C7uukapR.js","./CloudForgotPasswordView-CPI_0LyH.css","./CloudSurveyView-CE9A4vcE.js","./auth-B908xRS2.js","./CloudSurveyView-BS7kjG6B.css","./UserCheckView-DTJ1XEiJ.js","./CloudSorryContactSupportView-BvprZRoD.js","./CloudSorryContactSupportView-cvR6d1qS.css","./CloudAuthTimeoutView-BMw1zscP.js","./CloudSubscriptionRedirectView-CNM67arn.js","./comfy-logo-single-CmiUbL12.js","./subscriptionCheckoutUtil-nZtx3Tgt.js"])))=>i.map(i=>d[i]);
import"./rolldown-runtime-DIIn1E2Q.js";import{ct as e}from"./vendor-primevue-BDZ_jj__.js";var t=[{path:`/cloud`,component:()=>e(()=>import(`./CloudLayoutView-5ImVSwWL.js`),__vite__mapDeps([0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46]),import.meta.url),children:[{path:`login`,name:`cloud-login`,component:()=>e(()=>import(`./CloudLoginView-DHbWe4RP.js`),__vite__mapDeps([47,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,48,49,44,45,50]),import.meta.url),beforeEnter:async(t,n,r)=>{if(!t.query.switchAccount){let{useCurrentUser:t}=await e(async()=>{let{useCurrentUser:e}=await import(`./useCurrentUser-zqQiqncr.js`);return{useCurrentUser:e}},__vite__mapDeps([51,3,2,4,5,1,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,44,45]),import.meta.url),{isLoggedIn:n}=t();if(n.value)return r({name:`cloud-user-check`})}r()}},{path:`signup`,name:`cloud-signup`,component:()=>e(()=>import(`./CloudSignupView-ZIdgJeyh.js`),__vite__mapDeps([52,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,53,54,49,48,44,45,55]),import.meta.url),beforeEnter:async(t,n,r)=>{if(!t.query.switchAccount){let{useCurrentUser:t}=await e(async()=>{let{useCurrentUser:e}=await import(`./useCurrentUser-zqQiqncr.js`);return{useCurrentUser:e}},__vite__mapDeps([51,3,2,4,5,1,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,44,45]),import.meta.url),{isLoggedIn:n}=t();if(n.value)return r({name:`cloud-user-check`})}r()}},{path:`forgot-password`,name:`cloud-forgot-password`,component:()=>e(()=>import(`./CloudForgotPasswordView-C7uukapR.js`),__vite__mapDeps([56,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,44,45,57]),import.meta.url)},{path:`survey`,name:`cloud-survey`,component:()=>e(()=>import(`./CloudSurveyView-CE9A4vcE.js`),__vite__mapDeps([58,1,2,3,4,6,7,8,9,10,11,15,21,18,23,13,14,24,16,25,26,27,28,33,59,12,36,44,60]),import.meta.url),meta:{requiresAuth:!0}},{path:`user-check`,name:`cloud-user-check`,component:()=>e(()=>import(`./UserCheckView-DTJ1XEiJ.js`),__vite__mapDeps([61,2,3,4,6,7,8,9,10,13,15,21,18,23,14,24,16,25,11,26,27,28,30,33,59,12,44]),import.meta.url),meta:{requiresAuth:!0}},{path:`sorry-contact-support`,name:`cloud-sorry-contact-support`,component:()=>e(()=>import(`./CloudSorryContactSupportView-BvprZRoD.js`),__vite__mapDeps([62,1,2,11,4,63]),import.meta.url)},{path:`auth-timeout`,name:`cloud-auth-timeout`,component:()=>e(()=>import(`./CloudAuthTimeoutView-BMw1zscP.js`),__vite__mapDeps([64,2,3,4,5,1,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,44,45]),import.meta.url),props:!0},{path:`subscribe`,name:`cloud-subscribe`,component:()=>e(()=>import(`./CloudSubscriptionRedirectView-CNM67arn.js`),__vite__mapDeps([65,2,3,4,5,1,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,66,67,44,45]),import.meta.url),meta:{requiresAuth:!0}}]}];export{t as cloudOnboardingRoutes};
//# sourceMappingURL=onboardingCloudRoutes-CN9olCIK.js.map