import"./vendor-primevue-BDZ_jj__.js";import"./vendor-other-CiPV8GBG.js";import"./api-Cw7jP9TY.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-Bsa2N3Sq.js";import"./i18n-CF_88JEG.js";import{t as e}from"./auth-B908xRS2.js";export{e as getSurveyCompletedStatus};