import"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-BDZ_jj__.js";import{F as e,I as t,O as n,R as r,Rt as i,Ut as a,_t as o,et as s,it as c,j as l}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-CiPV8GBG.js";import{n as u}from"./vendor-i18n-JbyM4Qz7.js";import"./i18n-CF_88JEG.js";import"./vendor-reka-ui-B53kLmAc.js";import{t as d}from"./Button-Ca3rDegY.js";import{t as f}from"./useExternalLink-BItqlDxr.js";var p={class:`flex h-110 max-w-96 flex-col gap-4 p-2`},m={class:`mb-2 text-2xl font-medium`},h={class:`mb-4 text-base`},g={class:`flex items-center justify-between`},_={class:`flex gap-2`},v=r({__name:`ApiNodesSignInContent`,props:{apiNodeNames:{},onLogin:{type:Function},onCancel:{type:Function}},setup(r){let{t:v}=u(),{buildDocsUrl:y}=f(),handleLearnMoreClick=()=>{window.open(y(`/tutorials/api-nodes/faq`,{includeLocale:!0}),`_blank`)};return(r,u)=>{let f=c(`ApiNodesList`);return s(),l(`div`,p,[n(`div`,m,a(i(v)(`apiNodesSignInDialog.title`)),1),n(`div`,h,a(i(v)(`apiNodesSignInDialog.message`)),1),t(f,{"node-names":r.apiNodeNames},null,8,[`node-names`]),n(`div`,g,[t(d,{variant:`textonly`,onClick:handleLearnMoreClick},{default:o(()=>[e(a(i(v)(`g.learnMore`)),1)]),_:1}),n(`div`,_,[t(d,{variant:`secondary`,onClick:u[0]||=e=>r.onCancel?.()},{default:o(()=>[e(a(i(v)(`g.cancel`)),1)]),_:1}),t(d,{onClick:u[1]||=e=>r.onLogin?.()},{default:o(()=>[e(a(i(v)(`g.login`)),1)]),_:1})])])])}}});export{v as default};
//# sourceMappingURL=ApiNodesSignInContent-B8qA_K9T.js.map