import"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-BDZ_jj__.js";import"./vendor-firebase-D7u00oy9.js";import{D as e,R as t,Rt as n,et as r,k as i,ot as a}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-CiPV8GBG.js";import"./useFeatureFlags-CeS8LuDc.js";import"./api-Cw7jP9TY.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-Bsa2N3Sq.js";import"./i18n-CF_88JEG.js";import"./vendor-reka-ui-B53kLmAc.js";import"./Button-Ca3rDegY.js";import{Mi as o}from"./dialogService-CfgsFapJ.js";import"./formatUtil-CeKPWstn.js";import"./dialogStore-G2juoay4.js";import"./userStore-Czt6jT20.js";import"./useErrorHandling-DXaBpHI1.js";import"./extensionStore-MnMxnUwx.js";import"./useExternalLink-BItqlDxr.js";import"./vendor-tiptap-Bk1lVUYZ.js";import"./markdownRendererUtil-_EbNpPBW.js";import"./Popover-CXKWNrM3.js";import"./electronDownloadStore-DudKQmD7.js";import{t as s}from"./ComfyQueueButton-Hqh0Z3Xn.js";import{t as c}from"./SubscribeToRun-BTaVIhAv.js";var l=t({__name:`CloudRunButtonWrapper`,setup(t){let{isActiveSubscription:l}=o(),u=e(()=>l.value?s:c);return(e,t)=>(r(),i(a(u.value),{key:n(l)?`queue`:`subscribe`}))}});export{l as default};
//# sourceMappingURL=CloudRunButtonWrapper-Ca9V_a8g.js.map