import"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-BDZ_jj__.js";import"./vendor-firebase-D7u00oy9.js";import{F as e,I as t,O as n,R as r,Rt as i,Ut as a,_t as o,et as s,j as c}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-CiPV8GBG.js";import"./useFeatureFlags-CeS8LuDc.js";import"./api-Cw7jP9TY.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-Bsa2N3Sq.js";import"./i18n-CF_88JEG.js";import"./vendor-reka-ui-B53kLmAc.js";import{t as l}from"./Button-Ca3rDegY.js";import{Mi as u}from"./dialogService-CfgsFapJ.js";import"./formatUtil-CeKPWstn.js";import{t as d}from"./dialogStore-G2juoay4.js";import"./userStore-Czt6jT20.js";import"./useErrorHandling-DXaBpHI1.js";import"./extensionStore-MnMxnUwx.js";import"./useExternalLink-BItqlDxr.js";import"./vendor-tiptap-Bk1lVUYZ.js";import"./markdownRendererUtil-_EbNpPBW.js";import"./Popover-CXKWNrM3.js";import"./electronDownloadStore-DudKQmD7.js";var f={class:`flex w-full max-w-[512px] flex-col rounded-2xl border border-border-default bg-base-background`},p={class:`flex h-12 items-center justify-between border-b border-border-default px-4`},m={class:`m-0 text-sm font-normal text-base-foreground`},h=[`aria-label`],g={class:`flex flex-col gap-4 p-4`},_={class:`m-0 text-sm text-muted-foreground`},v={class:`flex items-center justify-end gap-4 p-4`},y=r({__name:`InviteMemberUpsellDialogContent`,setup(r){let y=d(),{isActiveSubscription:b,showSubscriptionDialog:x}=u();function onDismiss(){y.closeDialog({key:`invite-member-upsell`})}function onUpgrade(){y.closeDialog({key:`invite-member-upsell`}),x()}return(r,u)=>(s(),c(`div`,f,[n(`div`,p,[n(`h2`,m,a(i(b)?r.$t(`workspacePanel.inviteUpsellDialog.titleSingleSeat`):r.$t(`workspacePanel.inviteUpsellDialog.titleNotSubscribed`)),1),n(`button`,{class:`focus-visible:ring-secondary-foreground cursor-pointer rounded-sm border-none bg-transparent p-0 text-muted-foreground transition-colors hover:text-base-foreground focus-visible:ring-1 focus-visible:outline-none`,"aria-label":r.$t(`g.close`),onClick:onDismiss},u[0]||=[n(`i`,{class:`pi pi-times size-4`},null,-1)],8,h)]),n(`div`,g,[n(`p`,_,a(i(b)?r.$t(`workspacePanel.inviteUpsellDialog.messageSingleSeat`):r.$t(`workspacePanel.inviteUpsellDialog.messageNotSubscribed`)),1)]),n(`div`,v,[t(l,{variant:`muted-textonly`,onClick:onDismiss},{default:o(()=>[e(a(r.$t(`g.cancel`)),1)]),_:1}),t(l,{variant:`primary`,size:`lg`,onClick:onUpgrade},{default:o(()=>[e(a(i(b)?r.$t(`workspacePanel.inviteUpsellDialog.upgradeToCreator`):r.$t(`workspacePanel.inviteUpsellDialog.viewPlans`)),1)]),_:1})])]))}});export{y as default};
//# sourceMappingURL=InviteMemberUpsellDialogContent-CcC6eB8L.js.map