import"./rolldown-runtime-DIIn1E2Q.js";import{i as e,n as t}from"./vendor-primevue-BDZ_jj__.js";import"./vendor-firebase-D7u00oy9.js";import{F as n,I as r,R as i,Rt as a,Ut as o,_t as s,et as c,k as l,kt as u}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-CiPV8GBG.js";import"./useFeatureFlags-CeS8LuDc.js";import"./api-Cw7jP9TY.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-Bsa2N3Sq.js";import"./i18n-CF_88JEG.js";import"./vendor-reka-ui-B53kLmAc.js";import{t as d}from"./Button-Ca3rDegY.js";import{ji as f}from"./dialogService-CfgsFapJ.js";import"./formatUtil-CeKPWstn.js";import"./dialogStore-G2juoay4.js";import"./userStore-Czt6jT20.js";import"./useErrorHandling-DXaBpHI1.js";import"./extensionStore-MnMxnUwx.js";import"./useExternalLink-BItqlDxr.js";import"./vendor-tiptap-Bk1lVUYZ.js";import"./markdownRendererUtil-_EbNpPBW.js";import"./Popover-CXKWNrM3.js";import"./electronDownloadStore-DudKQmD7.js";import{i as p}from"./signInSchema-PuiTYtwA.js";import{t as m}from"./PasswordFields-DqvHzjK4.js";var h=i({__name:`UpdatePasswordContent`,props:{onSuccess:{type:Function}},setup(i){let h=f(),g=u(!1),onSubmit=async e=>{if(e.valid){g.value=!0;try{await h.updatePassword(e.values.password),i.onSuccess()}finally{g.value=!1}}};return(i,u)=>(c(),l(a(e),{class:`flex w-96 flex-col gap-6`,resolver:a(t)(a(p)),onSubmit},{default:s(()=>[r(m),r(d,{type:`submit`,class:`mt-4 h-10 font-medium`,loading:g.value},{default:s(()=>[n(o(i.$t(`userSettings.updatePassword`)),1)]),_:1},8,[`loading`])]),_:1},8,[`resolver`]))}});export{h as default};
//# sourceMappingURL=UpdatePasswordContent-37ITL9Au.js.map