import"./rolldown-runtime-DIIn1E2Q.js";import{O as e,et as t,j as n}from"./vendor-vue-core-DO0afONr.js";import{t as r}from"./_plugin-vue_export-helper-Wc9cjhKh.js";var i={},a={class:`relative size-full overflow-hidden rounded-sm`};function _sfc_render(r,i){return t(),n(`div`,a,i[0]||=[e(`div`,{class:`flex size-full items-center justify-center bg-modal-card-placeholder-background transition-transform duration-300 group-hover:scale-105 group-data-[selected=true]:scale-105`},[e(`i`,{class:`icon-[lucide--text] text-3xl text-base-foreground`})],-1)])}var o=r(i,[[`render`,_sfc_render]]);export{o as default};
//# sourceMappingURL=MediaTextTop-Jpmx1Rsa.js.map