import"./rolldown-runtime-DIIn1E2Q.js";import{Q as e,i as t,n,r,rt as i}from"./vendor-primevue-BDZ_jj__.js";import{A as a,D as o,F as s,I as c,O as l,R as u,Rt as d,Ut as f,_t as p,et as m,j as h,k as g}from"./vendor-vue-core-DO0afONr.js";import{Q as _}from"./vendor-vueuse-DUMtJaL2.js";import{n as v}from"./vendor-i18n-JbyM4Qz7.js";import{t as y}from"./Button-Ca3rDegY.js";import{Vi as b}from"./dialogService-CfgsFapJ.js";import{r as x}from"./signInSchema-PuiTYtwA.js";import{t as S}from"./PasswordFields-DqvHzjK4.js";var C={class:`mb-2 text-base font-medium opacity-80`,for:`comfy-org-sign-up-email`},w={key:0,class:`text-red-500`},T=u({__name:`SignUpForm`,emits:[`submit`],setup(u,{emit:T}){let{t:E}=v(),D=b(),O=o(()=>D.loading),k=T,A=_(e=>{e.valid&&k(`submit`,e.values)},1500);return(o,u)=>(m(),g(d(t),{class:`flex flex-col gap-6`,resolver:d(n)(d(x)),onSubmit:d(A)},{default:p(t=>[c(d(r),{name:`email`,class:`flex flex-col gap-2`},{default:p(e=>[l(`label`,C,f(d(E)(`auth.signup.emailLabel`)),1),c(d(i),{"pt:root:id":`comfy-org-sign-up-email`,"pt:root:autocomplete":`email`,class:`h-10`,type:`text`,placeholder:d(E)(`auth.signup.emailPlaceholder`),invalid:e.invalid},null,8,[`placeholder`,`invalid`]),e.error?(m(),h(`small`,w,f(e.error.message),1)):a(``,!0)]),_:1}),c(S),O.value?(m(),g(d(e),{key:0,class:`mx-auto size-8`})):(m(),g(y,{key:1,type:`submit`,class:`mt-4 h-10 font-medium`,disabled:!t.valid},{default:p(()=>[s(f(d(E)(`auth.signup.signUpButton`)),1)]),_:2},1032,[`disabled`]))]),_:1},8,[`resolver`,`onSubmit`]))}});export{T as t};
//# sourceMappingURL=SignUpForm-Dc6zuXxy.js.map