import"./rolldown-runtime-DIIn1E2Q.js";import"./vendor-primevue-BDZ_jj__.js";import"./vendor-firebase-D7u00oy9.js";import{D as e,pt as t}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-CiPV8GBG.js";import{i as n}from"./useFeatureFlags-CeS8LuDc.js";import"./api-Cw7jP9TY.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-Bsa2N3Sq.js";import{o as r}from"./i18n-CF_88JEG.js";import"./vendor-reka-ui-B53kLmAc.js";import"./Button-Ca3rDegY.js";import{b as i,ur as a}from"./dialogService-CfgsFapJ.js";import"./formatUtil-CeKPWstn.js";import"./dialogStore-G2juoay4.js";import"./userStore-Czt6jT20.js";import"./useErrorHandling-DXaBpHI1.js";import"./extensionStore-MnMxnUwx.js";import"./useExternalLink-BItqlDxr.js";import"./vendor-tiptap-Bk1lVUYZ.js";import"./markdownRendererUtil-_EbNpPBW.js";import"./Popover-CXKWNrM3.js";import"./electronDownloadStore-DudKQmD7.js";var o=e(()=>{let e=[],t=n.value.server_health_alert;return t&&e.push({text:t.message,label:t.badge,variant:t.severity??`error`,tooltip:t.tooltip}),e}),s=i();t(()=>s.canvas,e=>{e&&(e.info_text=r(`g.comfyCloud`))},{immediate:!0}),a().registerExtension({name:`Comfy.Cloud.Badges`,get topbarBadges(){return o.value}});
//# sourceMappingURL=cloudBadges-C54knVRj.js.map