import"./rolldown-runtime-DIIn1E2Q.js";import{t as e}from"./types-DPJvCrdo.js";var t={DISTRIBUTION:`tf_42243568391700`,ANONYMOUS_EMAIL:`tf_anonymous_requester_email`,EMAIL:`tf_40029135130388`,USER_ID:`tf_42515251051412`};function getDistribution(){return e?`ccloud`:`oss`}var n=`https://support.comfy.org/hc/en-us/requests/new`,r=`43066738713236`;function buildFeedbackUrl(){return`${n}?${new URLSearchParams({ticket_form_id:r,[t.DISTRIBUTION]:getDistribution()}).toString()}`}function buildSupportUrl(e){let r=new URLSearchParams({[t.DISTRIBUTION]:getDistribution()});return e?.userEmail&&(r.append(t.ANONYMOUS_EMAIL,e.userEmail),r.append(t.EMAIL,e.userEmail)),e?.userId&&r.append(t.USER_ID,e.userId),`${n}?${r.toString()}`}export{buildSupportUrl as n,buildFeedbackUrl as t};
//# sourceMappingURL=config-jWZh4ja0.js.map