import"./rolldown-runtime-DIIn1E2Q.js";import{D as e}from"./vendor-primevue-BDZ_jj__.js";import"./vendor-firebase-D7u00oy9.js";import{A as t,Bt as n,D as r,F as i,I as a,O as o,R as s,Rt as c,S as l,Ut as u,_t as d,et as f,j as p,nt as m,ut as h}from"./vendor-vue-core-DO0afONr.js";import"./vendor-other-CiPV8GBG.js";import"./useFeatureFlags-CeS8LuDc.js";import"./api-Cw7jP9TY.js";import"./vendor-markdown-Da9QPS2x.js";import"./colorUtil-Bsa2N3Sq.js";import"./i18n-CF_88JEG.js";import"./vendor-reka-ui-B53kLmAc.js";import{t as g}from"./Button-Ca3rDegY.js";import{i as _}from"./dialogService-CfgsFapJ.js";import"./formatUtil-CeKPWstn.js";import"./dialogStore-G2juoay4.js";import"./userStore-Czt6jT20.js";import"./useErrorHandling-DXaBpHI1.js";import"./extensionStore-MnMxnUwx.js";import"./useExternalLink-BItqlDxr.js";import"./vendor-tiptap-Bk1lVUYZ.js";import"./markdownRendererUtil-_EbNpPBW.js";import"./Popover-CXKWNrM3.js";import"./electronDownloadStore-DudKQmD7.js";var v={class:`w-113 max-w-md space-y-4 p-4`},y={class:`text-sm/tight text-muted-foreground`},b={class:`font-medium text-base-foreground`},x={class:`space-y-2`},S={class:`flex min-w-0 flex-1 items-center gap-2 text-wrap`},C={class:`flex size-8 shrink-0 items-center justify-center rounded-lg border border-border-subtle bg-secondary-background`},w={key:1,class:`text-xs font-normal text-base-foreground`},T={class:`flex min-w-0 flex-1 flex-col gap-0.5`},E={class:`text-sm/tight font-normal text-base-foreground`},D={class:`text-sm/tight font-normal text-muted-foreground`},O=s({__name:`ValueControlPopover`,props:{modelValue:{},modelModifiers:{}},emits:[`update:modelValue`],setup(s){let O=_(),k=[{mode:`fixed`,icon:`icon-[lucide--pencil-off]`,title:`fixed`,description:`fixedDesc`},{mode:`increment`,text:`+1`,title:`increment`,description:`incrementDesc`},{mode:`decrement`,text:`-1`,title:`decrement`,description:`decrementDesc`},{mode:`randomize`,icon:`icon-[lucide--shuffle]`,title:`randomize`,description:`randomizeDesc`}],A=r(()=>O.get(`Comfy.WidgetControlMode`)),j=h(s,`modelValue`);return(r,s)=>(f(),p(`div`,v,[o(`div`,y,[i(u(r.$t(`widgets.valueControl.header.prefix`))+` `,1),o(`span`,b,u(A.value===`before`?r.$t(`widgets.valueControl.header.before`):r.$t(`widgets.valueControl.header.after`)),1),i(` `+u(r.$t(`widgets.valueControl.header.postfix`)),1)]),o(`div`,x,[(f(),p(l,null,m(k,i=>a(g,{key:i.mode,as:`label`,variant:`textonly`,size:`lg`,class:`flex h-[unset] w-full items-center justify-between gap-7 py-2 text-left`,for:i.mode},{default:d(()=>[o(`div`,S,[o(`div`,C,[i.icon?(f(),p(`i`,{key:0,class:n([i.icon,`text-base text-base-foreground`])},null,2)):t(``,!0),i.text?(f(),p(`span`,w,u(i.text),1)):t(``,!0)]),o(`div`,T,[o(`div`,E,[o(`span`,null,u(r.$t(`widgets.valueControl.${i.title}`)),1)]),o(`div`,D,u(r.$t(`widgets.valueControl.${i.description}`)),1)])]),a(c(e),{modelValue:j.value,"onUpdate:modelValue":s[0]||=e=>j.value=e,class:`shrink`,"input-id":i.mode,value:i.mode},null,8,[`modelValue`,`input-id`,`value`])]),_:2},1032,[`for`])),64))])]))}});export{O as default};
//# sourceMappingURL=ValueControlPopover-CvV9082Q.js.map