import"./rolldown-runtime-DIIn1E2Q.js";import{D as e,kt as t}from"./vendor-vue-core-DO0afONr.js";import{i as n}from"./useFeatureFlags-CeS8LuDc.js";import{ea as r}from"./dialogService-CfgsFapJ.js";function useFreeTierOnboarding(){let i=t(!1),a=e(()=>r(`free`)),o=e(()=>n.value.new_free_tier_subscriptions??!1);function switchToEmailForm(){i.value=!0}function switchToSocialLogin(){i.value=!1}return{showEmailForm:i,freeTierCredits:a,isFreeTierEnabled:o,switchToEmailForm,switchToSocialLogin}}var decodeQueryParam=e=>{try{return decodeURIComponent(e)}catch{return null}},isSafeInternalRedirectPath=e=>e.startsWith(`/`)&&!e.startsWith(`//`),getSafePreviousFullPath=e=>{let t=e.previousFullPath,n=Array.isArray(t)?t[0]:t;if(!n)return null;let r=decodeQueryParam(n);return r&&isSafeInternalRedirectPath(r)?r:null};export{useFreeTierOnboarding as n,getSafePreviousFullPath as t};
//# sourceMappingURL=previousFullPath-DWscR1ic.js.map