import"./rolldown-runtime-DIIn1E2Q.js";import{D as e,G as t,I as n,O as r,R as i,Ut as a,et as o,j as s,ut as c}from"./vendor-vue-core-DO0afONr.js";import{t as l}from"./ScrubableNumberInput-CRrR3VyE.js";var u={class:`grid grid-cols-[auto_1fr] gap-x-2 gap-y-1`},d={class:`content-center text-xs text-node-component-slot-text`},f={class:`content-center text-xs text-node-component-slot-text`},p={class:`content-center text-xs text-node-component-slot-text`},m={class:`content-center text-xs text-node-component-slot-text`},h=i({__name:`WidgetBoundingBox`,props:t({disabled:{type:Boolean,default:!1}},{modelValue:{default:()=>({x:0,y:0,width:512,height:512})},modelModifiers:{}}),emits:[`update:modelValue`],setup(t){let i=c(t,`modelValue`),h=e({get:()=>i.value.x,set:e=>{i.value={...i.value,x:e}}}),g=e({get:()=>i.value.y,set:e=>{i.value={...i.value,y:e}}}),_=e({get:()=>i.value.width,set:e=>{i.value={...i.value,width:e}}}),v=e({get:()=>i.value.height,set:e=>{i.value={...i.value,height:e}}});return(e,t)=>(o(),s(`div`,u,[r(`label`,d,a(e.$t(`boundingBox.x`)),1),n(l,{modelValue:h.value,"onUpdate:modelValue":t[0]||=e=>h.value=e,min:0,step:1,disabled:e.disabled},null,8,[`modelValue`,`disabled`]),r(`label`,f,a(e.$t(`boundingBox.y`)),1),n(l,{modelValue:g.value,"onUpdate:modelValue":t[1]||=e=>g.value=e,min:0,step:1,disabled:e.disabled},null,8,[`modelValue`,`disabled`]),r(`label`,p,a(e.$t(`boundingBox.width`)),1),n(l,{modelValue:_.value,"onUpdate:modelValue":t[2]||=e=>_.value=e,min:1,step:1,disabled:e.disabled},null,8,[`modelValue`,`disabled`]),r(`label`,m,a(e.$t(`boundingBox.height`)),1),n(l,{modelValue:v.value,"onUpdate:modelValue":t[3]||=e=>v.value=e,min:1,step:1,disabled:e.disabled},null,8,[`modelValue`,`disabled`])]))}});export{h as t};
//# sourceMappingURL=WidgetBoundingBox-DFfb6lu8.js.map