import"./rolldown-runtime-DIIn1E2Q.js";import{A as e,Bt as t,D as n,O as r,R as i,Rt as a,S as o,et as s,j as c}from"./vendor-vue-core-DO0afONr.js";import{t as l}from"./src-NuWuoO1R.js";var u={class:`pointer-events-none absolute inset-0 flex items-center justify-center`},d=i({__name:`VideoPlayOverlay`,props:{visible:{type:Boolean,default:!0},size:{default:`md`},overlayClass:{default:`bg-black/15`}},setup(i){let d=n(()=>i.size===`sm`?`size-3`:`size-6`);return(n,i)=>n.visible?(s(),c(o,{key:0},[r(`div`,{class:t(a(l)(`pointer-events-none absolute inset-0`,n.overlayClass))},null,2),r(`div`,u,[r(`i`,{"aria-hidden":`true`,class:t(a(l)(`icon-[lucide--play] text-white`,d.value))},null,2)])],64)):e(``,!0)}});export{d as t};
//# sourceMappingURL=VideoPlayOverlay-HaJSLuhi.js.map