import"./rolldown-runtime-DIIn1E2Q.js";import{D as e,K as t,M as n,Pt as r,R as i,Rt as a,U as o,_t as s,et as c,k as l,kt as u,rt as d,tt as f}from"./vendor-vue-core-DO0afONr.js";import{O as p}from"./vendor-other-CiPV8GBG.js";import{Dt as m,Et as h,a as g,i as _}from"./vendor-reka-ui-B53kLmAc.js";import{t as v}from"./src-NuWuoO1R.js";var y=Symbol(`toggleGroupVariant`),b=p({base:`flex items-center justify-center gap-1`,variants:{variant:{default:`bg-transparent`,outline:`bg-transparent`}},defaultVariants:{variant:`default`}}),x=p({base:[`inline-flex items-center justify-center rounded`,`border-none cursor-pointer appearance-none`,`text-center font-normal`,`transition-all duration-150 ease-in-out`,`focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring`,`disabled:pointer-events-none disabled:opacity-50 disabled:cursor-not-allowed`,`data-[state=on]:bg-interface-menu-component-surface-selected data-[state=on]:text-text-primary`],variants:{variant:{default:`bg-transparent text-text-secondary hover:bg-interface-menu-component-surface-selected/50`,outline:`border border-border-default bg-transparent text-text-secondary hover:bg-secondary-background`},size:{default:`h-7 px-3 text-sm`,sm:`h-6 px-5 py-[5px] text-xs`,lg:`h-9 px-4 text-sm`}},defaultVariants:{variant:`default`,size:`default`}}),S=i({__name:`ToggleGroup`,props:{class:{},variant:{default:`default`},rovingFocus:{type:Boolean},disabled:{type:Boolean},orientation:{},dir:{},loop:{type:Boolean},asChild:{type:Boolean},as:{},name:{},required:{type:Boolean},type:{},modelValue:{},defaultValue:{}},emits:[`update:modelValue`],setup(e,{emit:i}){let o=h(n(e,[`class`,`variant`]),i);return f(y,r(()=>e.variant)),(n,r)=>(c(),l(a(g),t(a(o),{class:a(v)(a(b)({variant:n.variant}),e.class)}),{default:s(()=>[d(n.$slots,`default`)]),_:3},16,[`class`]))}}),C=i({__name:`ToggleGroupItem`,props:{class:{},variant:{},size:{default:`default`},value:{},disabled:{type:Boolean},asChild:{type:Boolean},as:{}},setup(r){let i=n(r,[`class`,`variant`,`size`]),f=o(y,u(`default`)),p=m(i),h=e(()=>r.variant??f.value??`default`);return(e,n)=>(c(),l(a(_),t(a(p),{class:a(v)(a(x)({variant:h.value,size:e.size}),`min-w-0 flex-1 truncate`,r.class)}),{default:s(()=>[d(e.$slots,`default`)]),_:3},16,[`class`]))}});export{S as n,C as t};
//# sourceMappingURL=toggle-group-uNHCQYph.js.map