import"./rolldown-runtime-DIIn1E2Q.js";import{D as e,F as t,O as n,R as r,Ut as i,_t as a,at as o,et as s,k as c,vt as l}from"./vendor-vue-core-DO0afONr.js";import{t as u}from"./types-DPJvCrdo.js";import{l as d,r as f}from"./vendor-vueuse-DUMtJaL2.js";import{n as p}from"./vendor-i18n-JbyM4Qz7.js";import{t as m}from"./telemetry-B-mZAUOK.js";import{t as h}from"./Button-Ca3rDegY.js";import{Mi as g}from"./dialogService-CfgsFapJ.js";var _=r({__name:`SubscribeToRun`,setup(r){let{t:_}=p(),v=d(f).greaterOrEqual(`md`),y=e(()=>v.value?_(`subscription.subscribeToRunFull`):_(`subscription.subscribeToRun`)),{showSubscriptionDialog:b}=g(),handleSubscribeToRun=()=>{u&&m()?.trackRunButton({subscribe_to_run:!0}),b()};return(e,r)=>{let u=o(`tooltip`);return l((s(),c(h,{class:`subscribe-to-run-button whitespace-nowrap`,variant:`gradient`,size:`sm`,"data-testid":`subscribe-to-run-button`,onClick:handleSubscribeToRun},{default:a(()=>[r[0]||=n(`i`,{class:`pi pi-lock`},null,-1),t(` `+i(y.value),1)]),_:1})),[[u,{value:e.$t(`subscription.subscribeToRunFull`),showDelay:600},void 0,{bottom:!0}]])}}});export{_ as t};
//# sourceMappingURL=SubscribeToRun-BTaVIhAv.js.map