import"./rolldown-runtime-DIIn1E2Q.js";import{Rt as e}from"./vendor-vue-core-DO0afONr.js";import{J as t}from"./api-Cw7jP9TY.js";var isNodeMissingDefinition=(e,t)=>{let n=e?.type;return n?!t[n]:!1},collectMissingNodes=(n,r)=>{if(!n)return[];let i=e(r);return t(n,e=>isNodeMissingDefinition(e,i))},graphHasMissingNodes=(e,t)=>collectMissingNodes(e,t).length>0;export{graphHasMissingNodes as t};
//# sourceMappingURL=graphHasMissingNodes-CpoI5poz.js.map